==> flulm_auth-0.0.1.tar.gz: android/src/main/java/com/awesome/flulm_auth/handler/LmAPiHandler.kt <==
/*
 * Copyright (C) 2018 The OpenFlutter Organization
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.awesome.flulm_auth.handler

import com.awesome.flulm_auth.constant.LmPluginKeys
import com.awesomeglobal.paysdk.auth.LMAPIFactory
import com.awesomeglobal.paysdk.auth.LMAuth
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.PluginRegistry

object LmAPiHandler {

    private var registrar: PluginRegistry.Registrar? = null
    var lmAuth: LMAuth? = null


    fun setRegistrar(registrar: PluginRegistry.Registrar) {
        LmAPiHandler.registrar = registrar
    }


    fun registerApp(call: MethodCall, result: MethodChannel.Result) {

        if (call.argument<Boolean>(LmPluginKeys.ANDROID) == false) {
            return
        }

        if (lmAuth != null) {
            result.success(mapOf(
                    LmPluginKeys.PLATFORM to LmPluginKeys.ANDROID,
                    LmPluginKeys.RESULT to true
            ))
            return
        }

        val appId: String? = call.argument(LmPluginKeys.APP_ID)
        if (appId.isNullOrBlank()) {
            result.error("invalid app id", "are you sure your app id is correct ?", appId)
            return
        }


        val api = LMAPIFactory.createLMAPI(registrar!!.context().applicationContext, appId)
        val registered = api.registerApp(appId)
        lmAuth = api
        result.success(mapOf(
                LmPluginKeys.PLATFORM to LmPluginKeys.ANDROID,
                LmPluginKeys.RESULT to registered
        ))
    }

    fun checkInstallation(result: MethodChannel.Result) {
        if (lmAuth == null) {
            result.error("lmapi not configured", "please config  lmapi first", null)
            return
        } else {
            result.success(lmAuth!!.isLMAppInstalled)
        }
    }

    fun getSupportAPI(result: MethodChannel.Result) {
        if (lmAuth == null) {
            result.error("lmapi not configured", "please config  lmapi first", null)
            return
        } else {
            result.success(lmAuth!!.lmAppSupportAPI)
        }
    }
}

==> flulm_auth-0.1.1.tar.gz: android/src/main/java/com/awesome/flulm_auth/handler/LmAPiHandler.kt <==
/*
 * Copyright (C) 2018 The OpenFlutter Organization
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.awesome.flulm_auth.handler

import com.awesome.flulm_auth.constant.LmPluginKeys
import com.awesomeglobal.paysdk.openapi.LMAPIFactory
import com.awesomeglobal.paysdk.openapi.LMAuth
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.PluginRegistry

object LmAPiHandler {

    private var registrar: PluginRegistry.Registrar? = null
    var lmAuth: LMAuth? = null


    fun setRegistrar(registrar: PluginRegistry.Registrar) {
        LmAPiHandler.registrar = registrar
    }


    fun registerApp(call: MethodCall, result: MethodChannel.Result) {

        if (call.argument<Boolean>(LmPluginKeys.ANDROID) == false) {
            return
        }

        if (lmAuth != null) {
            result.success(mapOf(
                    LmPluginKeys.PLATFORM to LmPluginKeys.ANDROID,
                    LmPluginKeys.RESULT to true
            ))
            return
        }

        val appId: String? = call.argument(LmPluginKeys.APP_ID)
        if (appId.isNullOrBlank()) {
            result.error("invalid app id", "are you sure your app id is correct ?", appId)
            return
        }


        val api = LMAPIFactory.createLMAPI(registrar!!.context().applicationContext, appId)
        val registered = api.registerApp(appId)
        lmAuth = api
        result.success(mapOf(
                LmPluginKeys.PLATFORM to LmPluginKeys.ANDROID,
                LmPluginKeys.RESULT to registered
        ))
    }

    fun checkInstallation(result: MethodChannel.Result) {
        if (lmAuth == null) {
            result.error("lmapi not configured", "please config  lmapi first", null)
            return
        } else {
            result.success(lmAuth!!.isLMAppInstalled)
        }
    }

    fun getSupportAPI(result: MethodChannel.Result) {
        if (lmAuth == null) {
            result.error("lmapi not configured", "please config  lmapi first", null)
            return
        } else {
            result.success(lmAuth!!.lmAppSupportAPI)
        }
    }
}
